FirestoreQueryFilterCompare

Enum FirestoreQueryFilterCompare 

pub enum FirestoreQueryFilterCompare {
    LessThan(String, FirestoreValue),
    LessThanOrEqual(String, FirestoreValue),
    GreaterThan(String, FirestoreValue),
    GreaterThanOrEqual(String, FirestoreValue),
    Equal(String, FirestoreValue),
    NotEqual(String, FirestoreValue),
    ArrayContains(String, FirestoreValue),
    In(String, FirestoreValue),
    ArrayContainsAny(String, FirestoreValue),
    NotIn(String, FirestoreValue),
}
Re-exports all public items from the db module.

The db module contains the core FirestoreDb client and functionalities for interacting with the Firestore database, such as CRUD operations, queries, and transactions. A field filter that compares a field to a value using a specific operator. The first String argument in each variant is the field path. The FirestoreValue is the value to compare against.

Variants



LessThan(String, FirestoreValue)

Field is less than the value.



LessThanOrEqual(String, FirestoreValue)

Field is less than or equal to the value.



GreaterThan(String, FirestoreValue)

Field is greater than the value.



GreaterThanOrEqual(String, FirestoreValue)

Field is greater than or equal to the value.



Equal(String, FirestoreValue)

Field is equal to the value.



NotEqual(String, FirestoreValue)

Field is not equal to the value.



ArrayContains(String, FirestoreValue)

Field (which must be an array) contains the value.



In(String, FirestoreValue)

Field’s value is IN the given array value. The FirestoreValue should be an array.



ArrayContainsAny(String, FirestoreValue)

Field (which must be an array) contains any of the values in the given array value. The FirestoreValue should be an array.



NotIn(String, FirestoreValue)

Field’s value is NOT IN the given array value. The FirestoreValue should be an array.